package operation

import (
	"shylinux.com/x/ice"
	"shylinux.com/x/icebergs/base/aaa"
	"shylinux.com/x/icebergs/base/mdb"
	"shylinux.com/x/icebergs/base/web"
	kit "shylinux.com/x/toolkits"

	"shylinux.com/x/operation/src/operation/model"
)

type container struct {
	Table
	order  string `data:"1"`
	fields string `data:"name,module,version"`
	create string `name:"create uid* domain module version" role:"leader"`
	remove string `name:"remove" role:"leader"`
	apply  string `name:"apply" role:"void"`
	rename string `name:"rename name" role:"void"`
	open   string `name:"open" role:"void"`
}

func (s container) Create(m *ice.Message, arg ...string) {
	s.Table.Insert(m, kit.Simple(arg, m.OptionSimple(model.CLOUD_UID))...)
}
func (s container) Rename(m *ice.Message, arg ...string) {
	s.Table.Update(m, m.OptionSimple(model.NAME), m.OptionSimple(model.CLOUD_UID, model.UID)...)
}
func (s container) List(m *ice.Message, arg ...string) {
	if len(arg) == 1 {
		s.Select(m, model.CLOUD_UID, arg[0], model.USER_UID, m.Option(model.USER_UID)).PushAction(s.Open, s.Rename)
		kit.If(m.Length() == 0, func() { m.EchoInfoButton("请申请云容器", s.Apply) })
		kit.If(s.IsLeader(m), func() { m.Action(s.Create, s.Apply) }, func() {
			if m.Length() > 0 {
				m.Action()
			}
		})
	} else {
		s.SelectDetail(m, model.UID, arg[1], model.CLOUD_UID, arg[0], model.USER_UID, m.Option(model.USER_UID)).PushAction(s.Open, s.Rename)
		m.EchoIFrame(web.S(arg[1]))
	}
	m.Display("").DisplayCSS("")
}
func (s container) Apply(m *ice.Message, arg ...string) {
	s.Transaction(m, func() {
		msg := m.Spawn()
		msg = s.Limit(msg, 1).SelectForUpdate(msg, "(user_uid IS NULL OR user_uid = '') AND cloud_uid = ?", m.Option(model.CLOUD_UID))
		if m.Warn(msg.Length() == 0, "容器不够用啦！") {
			return
		}
		s.Update(m, m.OptionSimple(model.USER_UID), msg.AppendSimple(model.UID)...)
		m.Cmd(web.SPACE, msg.Append(model.UID), aaa.USER, mdb.CREATE, aaa.TECH, m.Option(model.USER_UID), kit.Dict(ice.MSG_USERROLE, aaa.TECH))
	})
}
func (s container) Open(m *ice.Message, arg ...string) {
	m.ProcessOpen(m.Options(ice.MSG_USERPOD, "").MergePod(m.Option(model.UID)))
}

func init() { ice.TeamCtxCmd(container{}) }
